get_option_invisible <- function(default = TRUE) {
  getOption("envelope.invisible", default = default)
}

get_option_details <- function(default = TRUE) {
  getOption("envelope.details", default = default)
}
