LEVELS_ENCODING <- c("7bit", "quoted-printable", "base64")
LEVELS_PRIORITY <- c("non-urgent", "normal", "urgent")
LEVELS_IMPORTANCE <- c("low", "normal", "high")
LEVELS_MICALG <- c("pgp-sha256", "pgp-md5", "pgp-sha1", "pgp-ripemd160",
                   "pgp-md2", "pgp-tiger192", "pgp-haval-5-160")

CRLF <- "\r\n"
